@@ -18,7 +18,7 @@ def create_interpolator(method, values, F, M, S, npy=None,degree=0, log_level=0)
     elif method == "cubic":
         intr = Multivariate(values,F, M, S,npy, 3, log_level)
     elif method == "bspline":
-        intr = Bspline(values,F, M, S,npy, 3, log_level)
+        intr = Bspline(values,F, M, S,npy, 3, log_level) 
     else: #nearest is default
         intr = Nearest(values,F, M, S,npy,0,log_level)
     intr.init()
@@ -166,7 +166,7 @@ class Interpolator(ABC):
             row = []
             for j in range(len(unit_coords[0])):
                 vec = unit_coords[i][j]
-                if self.log_level > 0:
+                if self.log_level > 2:
                     print("Get value", vec.A,vec.B,vec.C)
                 if deriv == 2:
                     vec_val = self.get_laplacian(vec.A,vec.B,vec.C)
@@ -435,7 +435,7 @@ class Bspline(Interpolator):
             else:# //TODO                       
                 row[0] = self.initial_causal_coeffs(row, width, pole[k])            
             #/* causal recursion */
-            for n in range(width):            
+            for n in range(1,width):            
                 row[n] = row[n]+ pole[k] * row[n - 1]
             #/* anticausal initialization */
             if (mirror):
@@ -513,11 +513,11 @@ class Bspline(Interpolator):
         j = int(math.floor(y) - self.degree / 2)
         k = int(math.floor(z) - self.degree / 2)
 
-        for l in range(self.degree):        
+        for l in range(self.degree+1):        
+            i,j,k=i+1,j+1,k+1        
             xIndex[l] = i #if 71.1 passed in, for linear, we would want 71 and 72, 
             yIndex[l] = j
-            zIndex[l] = k
-            i,j,k=i+1,j+1,k+1        
+            zIndex[l] = k            
         #/* compute the interpolation weights */
         if (self.degree == 9):        
             xWeight = self.applyValue9(x, xIndex, weight_length)
@@ -541,11 +541,11 @@ class Bspline(Interpolator):
         #Perform interolation            
         spline_degree = self.degree
         w3 = 0.0
-        for k in range(spline_degree):
+        for k in range(spline_degree+1):
             w2 = 0.0
-            for j in range(spline_degree):
+            for j in range(spline_degree+1):
                 w1 = 0.0
-                for i in range(spline_degree):                
+                for i in range(spline_degree+1):                
                     w1 += xWeight[i] * self.get_coeff(xIndex[i], yIndex[j], zIndex[k],self._F,self._M,self._S)
                 w2 += yWeight[j] * w1
             w3 += zWeight[k] * w2
